@@ -129,12 +129,8 @@ def bake(ctx: click.Context) -> None:  # pylint: disable=too-many-statements
     """
     Renders various files based on an auxilium file. Will overwrite without asking.
     """
-    # with convert_runtime_to_click_error():
-    try:
+    with convert_runtime_to_click_error():
         ctx.obj.bake()
-    except Exception as err:
-        print(err)
-        raise
 
 
 @aux.command()
