@@ -9,14 +9,7 @@ from ._components import AllComponents
 from ._components._02_base import BaseComponent
 from ._gitlab import GitlabSetter
 from ._tick import TickSetter
-
-
-class LazyVersionStr:
-    def __str__(self) -> str:
-        # pylint: disable=import-outside-toplevel,cyclic-import
-        import adaux
-
-        return adaux.__version__
+from ._util import LazyVersionStr
 
 
 class CliMixin(BaseComponent):  # pylint: disable=too-many-ancestors
